@@ -14,7 +14,6 @@
 #    under the License.
 
 from manilaclient import base
-from manilaclient.common.apiclient import base as common_base
 from manilaclient import exceptions
 
 RESOURCES_PATH = '/security-services'
@@ -23,7 +22,7 @@ RESOURCE_NAME = 'security_service'
 RESOURCES_NAME = 'security_services'
 
 
-class SecurityService(common_base.Resource):
+class SecurityService(base.Resource):
     """Security service for Manila shares."""
     def __repr__(self):
         return "<SecurityService: %s>" % self.id
@@ -42,13 +41,15 @@ class SecurityServiceManager(base.ManagerWithFind):
 
     resource_class = SecurityService
 
-    def create(self, type, dns_ip=None, server=None, domain=None, user=None,
-               password=None, name=None, description=None):
+    def create(self, type, dns_ip=None, ou=None, server=None, domain=None,
+               user=None, password=None, name=None,
+               description=None):
         """Create security service for NAS.
 
         :param type: security service type - 'ldap', 'kerberos' or
                      'active_directory'
         :param dns_ip: dns ip address used inside tenant's network
+        :param ou: security service organizational unit
         :param server: security service server ip address or hostname
         :param domain: security service domain
         :param user: security identifier used by tenant
@@ -60,6 +61,8 @@ class SecurityServiceManager(base.ManagerWithFind):
         values = {'type': type}
         if dns_ip:
             values['dns_ip'] = dns_ip
+        if ou:
+            values['ou'] = ou
         if server:
             values['server'] = server
         if domain:
@@ -84,16 +87,18 @@ class SecurityServiceManager(base.ManagerWithFind):
         :rtype: :class:`SecurityService`
         """
         return self._get(
-            RESOURCE_PATH % common_base.getid(security_service),
+            RESOURCE_PATH % base.getid(security_service),
             RESOURCE_NAME,
         )
 
-    def update(self, security_service, dns_ip=None, server=None, domain=None,
-               password=None, user=None, name=None, description=None):
+    def update(self, security_service, dns_ip=None, ou=None, server=None,
+               domain=None, password=None, user=None, name=None,
+               description=None):
         """Updates a security service.
 
         :param security_service: security service to update.
         :param dns_ip: dns ip address used inside tenant's network
+        :param ou: security service organizational unit
         :param server: security service server ip address or hostname
         :param domain: security service domain
         :param user: security identifier used by tenant
@@ -106,6 +111,8 @@ class SecurityServiceManager(base.ManagerWithFind):
         values = {}
         if dns_ip is not None:
             values['dns_ip'] = dns_ip
+        if ou is not None:
+            values['ou'] = ou
         if server is not None:
             values['server'] = server
         if domain is not None:
@@ -130,7 +137,7 @@ class SecurityServiceManager(base.ManagerWithFind):
         body = {RESOURCE_NAME: values}
 
         return self._update(
-            RESOURCE_PATH % common_base.getid(security_service),
+            RESOURCE_PATH % base.getid(security_service),
             body,
             RESOURCE_NAME,
         )
@@ -140,7 +147,7 @@ class SecurityServiceManager(base.ManagerWithFind):
 
         :param security_service: security service to be deleted.
         """
-        self._delete(RESOURCE_PATH % common_base.getid(security_service))
+        self._delete(RESOURCE_PATH % base.getid(security_service))
 
     def list(self, detailed=True, search_opts=None):
         """Get a list of all security services.
